@@ -7,7 +7,7 @@
 
 #pragma once
 
-#include <AkonadiCore/Item>
+#include <Akonadi/Item>
 #include <QStringList>
 
 namespace Akonadi
